==> oscars_etl-0.1.1-py3-none-any.whl: oscars_etl/export.py <==

from oscars_etl.users import UserExporter
from oscars_etl.stats import StatsExporter


class ExporterCLI(object):

    @staticmethod
    def users2csv(ldap_username=None, ldap_password=None,
                  ldap_url='ipa01.vgt.vito.be',
                  csv_file='users.csv'):

        user_exporter = UserExporter(ldap_url,
                                     ldap_username, ldap_password)
        user_exporter.export_csv(csv_file)

    @staticmethod
    def users2db(ldap_username=None, ldap_password=None,
                 ldap_url='ipa01.vgt.vito.be',
                 db_host='postgresqldmz2.services.rscloud.vito.be', db_name='cvbdmz2',
                 db_username=None, db_password=None):

        user_exporter = UserExporter(ldap_url,
                                     ldap_username, ldap_password)
        user_exporter.export_db(db_host, db_name,
                                db_username, db_password)

    @staticmethod
    def stats2csv(es_hosts='es01.intern.vgt.vito.be, es02.intern.vgt.vito.be, es03.intern.vgt.vito.be',
                  csv_file='stats.csv',
                  start=None, end=None):

        stats_exporter = StatsExporter(es_hosts)
        stats_exporter.export_csv(start, end, csv_file)


    @staticmethod
    def stats2db(es_hosts='es01.intern.vgt.vito.be, es02.intern.vgt.vito.be, es03.intern.vgt.vito.be',
                 db_host='postgresqldmz2.services.rscloud.vito.be', db_name='cvbdmz2',
                 db_username=None, db_password=None,
                 start=None, end=None):

        stats_exporter = StatsExporter(es_hosts)
        stats_exporter.export_db(start, end, db_host, db_name, db_username, db_password)


if __name__ == '__main__':

    import os
    import logging
    import logging.config

    _basedir = os.path.dirname(os.path.realpath(__file__))
    logging.config.fileConfig(os.path.join(_basedir, 'logging.conf'),
                              disable_existing_loggers=False)

    import fire
    fire.Fire(ExporterCLI)

==> oscars_etl-0.1.7-py3-none-any.whl: oscars_etl/export.py <==

from oscars_etl.users import UserExporter
from oscars_etl.stats import StatsExporter


class ExporterCLI(object):

    @staticmethod
    def users2csv(ldap_username=None, ldap_password=None,
                  ldap_url='ipa01.vgt.vito.be',
                  csv_file='users.csv'):

        user_exporter = UserExporter(ldap_url,
                                     ldap_username, ldap_password)
        user_exporter.export_csv(csv_file)

    @staticmethod
    def users2db(ldap_username=None, ldap_password=None,
                 ldap_url='ipa01.vgt.vito.be',
                 db_host='postgresqldmz2.services.rscloud.vito.be', db_name='cvbdmz2',
                 db_username=None, db_password=None):

        user_exporter = UserExporter(ldap_url,
                                     ldap_username, ldap_password)
        user_exporter.export_db(db_host, db_name,
                                db_username, db_password)

    @staticmethod
    def stats2csv(es_hosts=['http://es01.intern.vgt.vito.be:9200', 'http://es02.intern.vgt.vito.be:9200', 'http://es03.intern.vgt.vito.be:9200'],
                  csv_file='stats.csv',
                  start=None, end=None):

        stats_exporter = StatsExporter(es_hosts)
        stats_exporter.export_csv(start, end, csv_file)


    @staticmethod
    def stats2db(es_hosts=['http://es01.intern.vgt.vito.be:9200', 'http://es02.intern.vgt.vito.be:9200', 'http://es03.intern.vgt.vito.be:9200'],
                 db_host='postgresqldmz2.services.rscloud.vito.be', db_name='cvbdmz2',
                 db_username=None, db_password=None,
                 start=None, end=None):

        stats_exporter = StatsExporter(es_hosts)
        stats_exporter.export_db(start, end, db_host, db_name, db_username, db_password)


if __name__ == '__main__':

    import os
    import logging
    import logging.config

    _basedir = os.path.dirname(os.path.realpath(__file__))
    logging.config.fileConfig(os.path.join(_basedir, 'logging.conf'),
                              disable_existing_loggers=False)

    import fire
    fire.Fire(ExporterCLI)
